@@ -28,39 +28,39 @@
 #include "gbcommon.h"
 
 
-GConfClient* gconf_client = NULL;
-	
+GConfClient *gconf_client = NULL;
+
 
 gboolean
 preferences_init()
 {
 	GB_LOG_FUNC
-	
+
 	gboolean ok = FALSE;
 	g_type_init();
 	gconf_client = gconf_client_get_default();
-	if(gconf_client == NULL) 
+	if(gconf_client == NULL)
 	{
-		g_critical("Failed to initialise gconf");
+		g_warning("preferences_init - Failed to initialise gconf");
 	}
 	else
 	{
-		gchar* tempdir = preferences_get_string(GB_TEMP_DIR);
-		if(tempdir == NULL)
-		{		
-		    gchar* temp_string = g_strdup_printf("GnomeBaker-%s", g_get_user_name());
-			tempdir = g_build_filename(g_get_tmp_dir(), temp_string, NULL);		
+		gchar *temp_dir = preferences_get_string(GB_TEMP_DIR);
+		if(temp_dir == NULL)
+		{
+		    gchar *temp_string = g_strdup_printf("GnomeBaker-%s", g_get_user_name());
+			temp_dir = g_build_filename(g_get_tmp_dir(), temp_string, NULL);
 			g_free(temp_string);
             temp_string = NULL;
-					
-			/* set up default values */			
+
+			/* set up default values */
 			preferences_set_string(GB_READER, "Device01");
-			preferences_set_string(GB_WRITER, "Device01");			
+			preferences_set_string(GB_WRITER, "Device01");
 			preferences_set_int(GB_CDWRITE_SPEED, 4);
 			preferences_set_int(GB_DVDWRITE_SPEED, 2);
 			preferences_set_bool(GB_DUMMY, FALSE);
 			preferences_set_bool(GB_EJECT, TRUE);
-			preferences_set_string(GB_TEMP_DIR, tempdir);
+			preferences_set_string(GB_TEMP_DIR, temp_dir);
 			preferences_set_bool(GB_FAST_BLANK, FALSE);
 			preferences_set_bool(GB_BURNFREE, FALSE);
 			preferences_set_bool(GB_SHOWHIDDEN, FALSE);
@@ -74,23 +74,22 @@ preferences_init()
 			preferences_set_bool(GB_SHOW_FILE_BROWSER, TRUE);
             preferences_set_bool(GB_JOLIET, TRUE);
             preferences_set_bool(GB_ROCKRIDGE, TRUE);
-            preferences_set_bool(GB_ONTHEFLY, TRUE);
-            preferences_set_bool(GB_ASK_ON_QUIT, TRUE);
+            preferences_set_bool(GB_ONTHEFLY, TRUE);            
             preferences_set_bool(GB_PLAY_SOUND, TRUE);
             preferences_set_int(GB_DATA_DISK_SIZE, 0);
             preferences_set_int(GB_AUDIO_DISK_SIZE, 0);
             preferences_set_bool(GB_CDRECORD_FORCE, FALSE);
-            
-            gchar* last_iso = preferences_get_default_iso();
+
+            gchar *last_iso = preferences_get_default_iso();
             preferences_set_string(GB_LAST_ISO, last_iso);
             g_free(last_iso);
-		}		
-		
-		gbcommon_mkdir(tempdir);
-		g_free(tempdir);			
+		}
+
+		gbcommon_mkdir(temp_dir);
+		g_free(temp_dir);
 		ok = TRUE;
 	}
-		
+
 	return ok;
 }
 
@@ -99,40 +98,51 @@ void
 preferences_finalise()
 {
     GB_LOG_FUNC
-    g_object_unref(G_OBJECT(gconf_client));   
+    g_object_unref(G_OBJECT(gconf_client));
 }
 
 
-gchar* 
+gchar *
 preferences_get_copy_data_cd_image()
 {
 	GB_LOG_FUNC
-	gchar* tempdir = preferences_get_string(GB_TEMP_DIR);
-	gchar* ret = g_build_filename(tempdir, "gnomebaker_copy_data_cd.iso", NULL);
-	g_free(tempdir);
+	gchar *temp_dir = preferences_get_string(GB_TEMP_DIR);
+	gchar *ret = g_build_filename(temp_dir, "gnomebaker_copy_data_cd.iso", NULL);
+	g_free(temp_dir);
 	return ret;
 }
 
 
-gchar* 
+gchar *
+preferences_get_copy_dvd_image()
+{
+    GB_LOG_FUNC
+    gchar *temp_dir = preferences_get_string(GB_TEMP_DIR);
+    gchar *ret = g_build_filename(temp_dir, "gnomebaker_copy_dvd.iso", NULL);
+    g_free(temp_dir);
+    return ret;
+}
+
+
+gchar *
 preferences_get_create_data_cd_image()
 {
 	GB_LOG_FUNC
-	gchar* tempdir = preferences_get_string(GB_TEMP_DIR);
-	gchar* ret = g_build_filename(tempdir, "gnomebaker_create_data_cd.iso", NULL);
-	g_free(tempdir);
+	gchar *temp_dir = preferences_get_string(GB_TEMP_DIR);
+	gchar *ret = g_build_filename(temp_dir, "gnomebaker_create_data_cd.iso", NULL);
+	g_free(temp_dir);
 	return ret;
 }
 
 
-gchar* 
+gchar *
 preferences_get_convert_audio_track_dir()
 {
 	GB_LOG_FUNC
-	gchar* tempdir = preferences_get_string(GB_TEMP_DIR);
-	gchar* path = g_build_filename(tempdir, "create_audiocd", NULL);
+	gchar *temp_dir = preferences_get_string(GB_TEMP_DIR);
+	gchar *path = g_build_filename(temp_dir, "create_audiocd", NULL);
 	gbcommon_mkdir(path);
-	g_free(tempdir);
+	g_free(temp_dir);
 	return path;
 }
 
@@ -140,20 +150,20 @@ preferences_get_convert_audio_track_dir()
 gchar*
 preferences_get_default_iso()
 {
-    GB_LOG_FUNC   
-    return g_build_filename(g_get_home_dir(), "gnomebaker.iso", NULL); 
+    GB_LOG_FUNC
+    return g_build_filename(g_get_home_dir(), "gnomebaker.iso", NULL);
 }
 
 
-GtkToolbarStyle  
+GtkToolbarStyle
 preferences_get_toolbar_style()
 {
 	GB_LOG_FUNC
 	GtkToolbarStyle ret = GTK_TOOLBAR_BOTH;
-	
-	gchar* style = gconf_client_get_string(gconf_client, GNOME_TOOLBAR_STYLE, NULL);
-	g_return_val_if_fail(style != NULL, ret);		
-			
+
+	gchar *style = gconf_client_get_string(gconf_client, GNOME_TOOLBAR_STYLE, NULL);
+	g_return_val_if_fail(style != NULL, ret);
+
 	if(g_ascii_strcasecmp(style, "both-horiz") == 0)
 		ret = GTK_TOOLBAR_BOTH_HORIZ;
 	else if(g_ascii_strcasecmp(style, "icons") == 0)
@@ -162,16 +172,16 @@ preferences_get_toolbar_style()
 		ret = GTK_TOOLBAR_TEXT;
 	else if(g_ascii_strcasecmp(style, "both") == 0)
 		ret = GTK_TOOLBAR_BOTH;
-	
+
 	GB_TRACE("preferences_get_toolbar_style - toolbar style [%s] [%d]\n", style, ret);
 	g_free(style);
-	
+
 	return ret;
 }
 
 
-gchar* 
-preferences_get_string(const gchar* key)
+gchar *
+preferences_get_string(const gchar *key)
 {
 	GB_LOG_FUNC
 	g_return_val_if_fail(key != NULL, NULL);
@@ -179,8 +189,8 @@ preferences_get_string(const gchar* key)
 }
 
 
-gboolean 
-preferences_get_bool(const gchar* key)
+gboolean
+preferences_get_bool(const gchar *key)
 {
 	GB_LOG_FUNC
 	g_return_val_if_fail(key != NULL, FALSE);
@@ -188,8 +198,8 @@ preferences_get_bool(const gchar* key)
 }
 
 
-gint 
-preferences_get_int(const gchar* key)
+gint
+preferences_get_int(const gchar *key)
 {
 	GB_LOG_FUNC
 	g_return_val_if_fail(key != NULL, -1);
@@ -197,8 +207,8 @@ preferences_get_int(const gchar* key)
 }
 
 
-gboolean 
-preferences_set_string(const gchar* key, const gchar* value)
+gboolean
+preferences_set_string(const gchar *key, const gchar *value)
 {
 	GB_LOG_FUNC
 	g_return_val_if_fail(key != NULL, FALSE);
@@ -206,8 +216,8 @@ preferences_set_string(const gchar* key, const gchar* value)
 }
 
 
-gboolean 
-preferences_set_bool(const gchar* key, const gboolean value)
+gboolean
+preferences_set_bool(const gchar *key, const gboolean value)
 {
 	GB_LOG_FUNC
 	g_return_val_if_fail(key != NULL, FALSE);
@@ -215,48 +225,65 @@ preferences_set_bool(const gchar* key, const gboolean value)
 }
 
 
-gboolean 
-preferences_set_int(const gchar* key, const gint value)
+gboolean
+preferences_set_int(const gchar *key, const gint value)
 {
 	GB_LOG_FUNC
 	g_return_val_if_fail(key != NULL, FALSE);
-	return gconf_client_set_int(gconf_client, key, value, NULL);	
+	return gconf_client_set_int(gconf_client, key, value, NULL);
 }
 
 
-gboolean 
-preferences_key_exists(const gchar* key)
+gboolean
+preferences_key_exists(const gchar *key)
 {
 	GB_LOG_FUNC
-	g_return_val_if_fail(key != NULL, FALSE);	
+	g_return_val_if_fail(key != NULL, FALSE);
 	return gconf_client_dir_exists(gconf_client, key, NULL);
 }
 
 
-GSList* 
-preferences_get_key_subkeys(const gchar* key)
+GSList*
+preferences_get_key_subkeys(const gchar *key)
 {
 	GB_LOG_FUNC
-	g_return_val_if_fail(key != NULL, NULL);	
+	g_return_val_if_fail(key != NULL, NULL);
 	return gconf_client_all_dirs(gconf_client, key, NULL);
 }
 
 
-gboolean 
-preferences_delete_key(const gchar* key)
+GSList*
+preferences_get_key_values(const gchar *key)
+{
+    GB_LOG_FUNC
+    g_return_val_if_fail(key != NULL, NULL);
+    GError *err = NULL;
+//    GSList *ret = gconf_client_get_list(gconf_client, key, GCONF_VALUE_STRING, NULL);
+//    if(err != NULL)
+//    {
+//        g_critical(err->message);
+//        g_error_free(err);
+//    }
+//    return ret;
+    return gconf_client_all_entries(gconf_client, key, NULL);
+}
+
+
+gboolean
+preferences_delete_key(const gchar *key)
 {
 	GB_LOG_FUNC
-	g_return_val_if_fail(key != NULL, FALSE);	
+	g_return_val_if_fail(key != NULL, FALSE);
 	return gconf_client_unset(gconf_client, key, NULL);
 }
 
 
 void
-preferences_register_notify(const gchar* key, GConfClientNotifyFunc func)
+preferences_register_notify(const gchar *key, GConfClientNotifyFunc func, gpointer user_data)
 {
 	GB_LOG_FUNC
-	g_return_if_fail(key != NULL);	
-	g_return_if_fail(func != NULL);	
+	g_return_if_fail(key != NULL);
+	g_return_if_fail(func != NULL);
 	gconf_client_add_dir(gconf_client, key, GCONF_CLIENT_PRELOAD_NONE, NULL);
-	gconf_client_notify_add(gconf_client, key, func, NULL, NULL, NULL);	
+	gconf_client_notify_add(gconf_client, key, func, user_data, NULL, NULL);
 }
