@@ -40,6 +40,7 @@
 #define GB_CLEANTEMPDIR 			GB_BASE_KEY "/CleanTempDir"
 #define GB_CREATEISOONLY 			GB_BASE_KEY "/CreateISOOnly"
 #define GB_WRITE_MODE 				GB_BASE_KEY "/WriteMode"
+#define GB_DVDWRITE_MODE            GB_BASE_KEY "/DvdWriteMode"
 #define GB_ALWAYS_SCAN				GB_BASE_KEY "/AlwaysScanOnStartup"
 #define GB_FORCE					GB_BASE_KEY "/Force"
 #define GB_FINALIZE					GB_BASE_KEY "/Finalize"
@@ -48,17 +49,21 @@
 #define GB_JOLIET                   GB_BASE_KEY "/Joliet"
 #define GB_ROCKRIDGE                GB_BASE_KEY "/RockRidge"
 #define GB_ONTHEFLY                 GB_BASE_KEY "/OnTheFly"
-#define GB_ASK_ON_QUIT				GB_BASE_KEY "/AskOnQuit"
 #define GB_PLAY_SOUND               GB_BASE_KEY "/PlaySound"
+#define GB_DATA_DISK_SIZE           GB_BASE_KEY "/DataDiskSize"
+#define GB_AUDIO_DISK_SIZE          GB_BASE_KEY "/AudioDiskSize"
+#define GB_CDRECORD_FORCE		    GB_BASE_KEY "/CDRecordForce"
+#define GB_LAST_ISO                 GB_BASE_KEY "/LastISO"
 
 #define GB_MAIN_WINDOW_HEIGHT		GB_BASE_KEY "/UI/MainWindowHeight"
 #define GB_MAIN_WINDOW_WIDTH		GB_BASE_KEY "/UI/MainWindowWidth"
 #define GB_MAIN_WINDOW_POSITION_X	GB_BASE_KEY "/UI/MainWindowPositionX"
 #define GB_MAIN_WINDOW_POSITION_Y	GB_BASE_KEY "/UI/MainWindowPositionY"
 #define GB_MAIN_WINDOW_MAXIMIZED	GB_BASE_KEY "/UI/MainWindowMaximized"
+#define GB_SCROLL_OUTPUT		    GB_BASE_KEY "/UI/ScrollOutput"
 
 #define GB_DEVICE_FORMAT 			"Device%.2d"
-#define GB_DEVICES_KEY				GB_BASE_KEY "/Devices" 
+#define GB_DEVICES_KEY				GB_BASE_KEY "/Devices"
 #define GB_DEVICE_KEY				GB_DEVICES_KEY "/" GB_DEVICE_FORMAT
 
 #define GB_DEVICE_NAME_LABEL		"/DeviceName"
@@ -78,20 +83,23 @@
 gboolean preferences_init();
 void preferences_finalise();
 
-gchar* preferences_get_copy_data_cd_image();
-gchar* preferences_get_create_data_cd_image();
-gchar* preferences_get_convert_audio_track_dir();
+gchar *preferences_get_copy_data_cd_image();
+gchar *preferences_get_copy_dvd_image();
+gchar *preferences_get_create_data_cd_image();
+gchar *preferences_get_convert_audio_track_dir();
+gchar *preferences_get_default_iso();
 GtkToolbarStyle preferences_get_toolbar_style();
 
-gchar* preferences_get_string(const gchar* key);
-gboolean preferences_get_bool(const gchar* key);
-gint preferences_get_int(const gchar* key);
-gboolean preferences_set_string(const gchar* key, const gchar* value);
-gboolean preferences_set_bool(const gchar* key, const gboolean value);
-gboolean preferences_set_int(const gchar* key, const gint value);
-gboolean preferences_key_exists(const gchar* key);
-GSList* preferences_get_key_subkeys(const gchar* key);
-gboolean preferences_delete_key(const gchar* key);
-void preferences_register_notify(const gchar* key, GConfClientNotifyFunc func);
+gchar *preferences_get_string(const gchar *key);
+gboolean preferences_get_bool(const gchar *key);
+gint preferences_get_int(const gchar *key);
+gboolean preferences_set_string(const gchar *key, const gchar *value);
+gboolean preferences_set_bool(const gchar *key, const gboolean value);
+gboolean preferences_set_int(const gchar *key, const gint value);
+gboolean preferences_key_exists(const gchar *key);
+GSList* preferences_get_key_subkeys(const gchar *key);
+GSList* preferences_get_key_values(const gchar *key);
+gboolean preferences_delete_key(const gchar *key);
+void preferences_register_notify(const gchar *key, GConfClientNotifyFunc func, gpointer user_data);
 
 #endif
