@@ -30,16 +30,16 @@
 #include <glade/glade.h>
 #include "exec.h"
 
-GtkWidget* progressdlg_new(const Exec* exec, GtkWindow* parent, GCallback callonprematureclose);
-void progressdlg_delete(GtkWidget* self);
+GtkWidget *progressdlg_new(const Exec *exec, GtkWindow *parent, GCallback call_on_premature_close);
+void progressdlg_delete(GtkWidget *self);
 void progressdlg_set_fraction(gfloat fraction);
-void progressdlg_append_output(const gchar* output);
-void progressdlg_set_status(const gchar* status);
+void progressdlg_append_output(const gchar *output);
+void progressdlg_set_status(const gchar *status);
 void progressdlg_pulse_start();
 void progressdlg_pulse_stop();
 void progressdlg_increment_exec_number();
-void progressdlg_finish(GtkWidget* self, const Exec* ex);
-GtkWindow* progressdlg_get_window();
+void progressdlg_finish(GtkWidget *self, const Exec *ex);
+GtkWindow *progressdlg_get_window();
 void progressdlg_start_approximation(gint seconds);
 void progressdlg_stop_approximation();
 
